# arpes.plotting.fermi\_surface module

**arpes.plotting.fermi\_surface.fermi\_surface\_slices(arr:
xarray.core.dataarray.DataArray, n\_slices=9, ev\_per\_slice=0.02,
bin=0.01, out=None,**kwargs)\*\*

**arpes.plotting.fermi\_surface.magnify\_circular\_regions\_plot(data:
Union\[xarray.core.dataarray.DataArray, xarray.core.dataset.Dataset\],
magnified\_points, mag=10, radius=0.05, cmap='viridis', color=None,
edgecolor='red', out=None, ax=None,**kwargs)\*\*
